#[repr(C)]pub struct PartialDateTime<'a> {
pub date: PartialDate<'a>,
pub time: PartialTime,
}Fields
date: PartialDate<'a>time: PartialTimeTrait Implementations
Sourceimpl TryFrom<PartialDateTime<'_>> for DateTimeFields
impl TryFrom<PartialDateTime<'_>> for DateTimeFields
Sourcetype Error = TemporalError
type Error = TemporalError
The type returned in the event of a conversion error.
Sourcefn try_from(other: PartialDateTime<'_>) -> Result<Self, TemporalError>
fn try_from(other: PartialDateTime<'_>) -> Result<Self, TemporalError>
Performs the conversion.
Sourceimpl TryFrom<PartialDateTime<'_>> for PartialDateTime
impl TryFrom<PartialDateTime<'_>> for PartialDateTime
Sourcetype Error = TemporalError
type Error = TemporalError
The type returned in the event of a conversion error.
Sourcefn try_from(other: PartialDateTime<'_>) -> Result<Self, TemporalError>
fn try_from(other: PartialDateTime<'_>) -> Result<Self, TemporalError>
Performs the conversion.